Enter Your Info Page | Dunkin' Donuts
Description: I just got a free beverage by signing up for DD Perks! You can too at www.ddperks.com.

Back

# ENTER YOUR INFO

You're almost there!

*Indicates required fields

## CHOOSE PAYMENT METHOD

You can choose to register with Visa Checkout, Google Wallet or enter in your credit card information.

Finish creating your account by completing the required fields and selecting submit.

*Security Code

- Edit
- Cancel

- Edit
- Cancel

OR

## Enter credit card information

*Credit Card Number

- master
- visa
- american express
- discover
- jcb
- dinner

*Expiration Date
*Security Code

### Where is my security code?

Your security code is a 4-digit code on the front of your American Express card as highlighted below:
Where is my security code?
Your security code is a 4-digit code on the front of your American Express card as highlighted below:

### Where is my security code?

Your security code is a 3-digit code on the back of your credit card as highlighted below:
Where is my security code?
Your security code is a 3-digit code on the back of your credit card as highlighted below:
ENABLE AUTO-RELOAD

### What is auto-reload?

Choose whether to reload your card when the balance drops below a specific amount, or to reload it per month or week. We'll take care of the rest!
What is auto-reload?
Choose whether to reload your card when the balance drops below a specific amount, or to reload it per month or week. We'll take care of the rest!
Charge my card:

When my balance is below

automatically add

Every month on the

day of the month

will be added to your card

Every week on

will be added to your card

NOTE: You've selected an auto-reload value that is higher than the initial amount you selected to put on your card. This means your card will automatically be reloaded with your selected value once you complete registration.
ADD A PROMO CODE

### What is a promo code?

If you received a promo code from a Dunkin' promotional event, enter it here.
What is a promo code?
If you received a promo code from a Dunkin' promotional event, enter it here.
Enter your promo code:
*First Name
*Last Name
*Billing Street Address
Billing Street Address 2
*ZIP Code
*City
*State
*Email Address
*Confirm Email Address
*Password

8-50 characters, must contain numbers & letters.

*Confirm Password
*Birthday
Receive a free beverage for your birthday.
*I agree with the Terms & Conditions
Please Wait...